@@ -1710,7 +1710,6 @@ Expression Analyzer::derivative(const QString& var)
 {
 	Q_ASSERT(m_exp.isCorrect());
 	
-	Expression exp;
 	QStringList vars;
 	Object* deriv=m_exp.tree();
 	if(m_exp.isLambda()){
@@ -1737,10 +1736,8 @@ Expression Analyzer::derivative(const QString& var)
 		lambda->appendBranch(bvar);
 	}
 	lambda->appendBranch(o);
-	
-	exp.setTree(lambda);
-	
-	return exp;
+	Expression::computeDepth(lambda);
+	return Expression(lambda);
 }
 
 Expression Analyzer::dependenciesToLambda() const
